@@ -63,6 +63,7 @@ CATEGORY_MAP = {
     "girlswithmuscle": "Girls with Muscle",
     "hatenablog"     : "HatenaBlog",
     "hbrowse"        : "HBrowse",
+    "hdoujin"        : "HDoujin Galleries",
     "hentai2read"    : "Hentai2Read",
     "hentaicosplay"  : "Hentai Cosplay",
     "hentaienvy"     : "HentaiEnvy",
@@ -90,6 +91,8 @@ CATEGORY_MAP = {
     "imagechest"     : "ImageChest",
     "imgdrive"       : "ImgDrive.net",
     "imgkiwi"        : "IMG.Kiwi",
+    "imglike"        : "Nude Celeb",
+    "imgpile"        : "imgpile",
     "imgtaxi"        : "ImgTaxi.com",
     "imgth"          : "imgth",
     "imgur"          : "imgur",
@@ -100,6 +103,7 @@ CATEGORY_MAP = {
     "itchio"         : "itch.io",
     "jpgfish"        : "JPG Fish",
     "kabeuchi"       : "かべうち",
+    "mangataro"      : "MangaTaro",
     "schalenetwork"  : "Schale Network",
     "leakgallery"    : "Leak Gallery",
     "livedoor"       : "livedoor Blog",
@@ -175,6 +179,7 @@ CATEGORY_MAP = {
     "thebarchive"    : "The /b/ Archive",
     "thecollection"  : "The /co/llection",
     "thecollectionS" : "The /co/llection",
+    "thehentaiworld" : "The Hentai World",
     "tiktok"         : "TikTok",
     "tmohentai"      : "TMOHentai",
     "tumblrgallery"  : "TumblrGallery",
@@ -259,6 +264,7 @@ SUBCATEGORY_MAP = {
     },
     "Danbooru": {
         "favgroup": "Favorite Groups",
+        "random"  : "Random Posts",
     },
     "desktopography": {
         "site": "",
